@@ -3,7 +3,7 @@ import threading
 import time
 import atexit
 
-print("Electron source controller: 0.0.8")
+print("Electron source controller: 0.0.11")
 
 from collections import deque
 
@@ -138,7 +138,17 @@ class ElectronGunControl:
     POLARITY_POS = b'p'
     POLARITY_NEG = b'n'
 
-    def __init__(self, portFile = '/dev/ttyU0'):
+    def __init__(self, portFile = None):
+        if not portFile:
+            portFile = '/dev/ttyU0'
+            try:
+                from quakesrctrl import config
+                if VISA_ID_EBEAM:
+                    portFile = VISA_ID_EBEAM
+            except Exception:
+                portFile = '/dev/ttyU0'
+                pass
+
         self.bufferInput = ElectronGunRingbuffer()
 
         self.port = False
@@ -499,6 +509,12 @@ class ElectronGunControl:
         # we really transmit the off condition
         time.sleep(2)
 
+    def noprotection(self, *ignore, sync = False):
+        if self.port == False:
+            raise ElectronGunNotConnected("Electron gun currently not connected")
+        cmd = b'$$$noprotection\n'
+        self.port.write(cmd)
+
     def setPSUPolarity(self, channel, polarity, *ignore, sync = False):
         if self.port == False:
             raise ElectronGunNotConnected("Electron gun currently not connected")
